@@ -1035,6 +1035,16 @@ class CollectionSerializer(
             )
         )
         res["webui_self"] = Link(href=instance.get_absolute_url())
+        res["webui_category"] = Link(
+            href=reverse(
+                "workspaces:collections:category_list",
+                kwargs={
+                    "wname": instance.workspace.name,
+                    "ccat": instance.category,
+                },
+            ),
+            type="category",
+        )
         return res
 
     def get_stats(self, instance: Collection) -> list[dict[str, Any]] | None:
