@@ -14,7 +14,7 @@ from typing import Any
 from debian.debian_support import Version
 from django.utils import timezone
 
-from debusine.artifacts import LintianArtifact
+from debusine.artifacts import LintianArtifact, SourcePackage
 from debusine.artifacts.models import (
     ArtifactCategory,
     DebianBinaryPackage,
@@ -22,10 +22,17 @@ from debusine.artifacts.models import (
     DebianUpload,
     get_source_package_version,
 )
-from debusine.db.models import Artifact, ArtifactRelation, WorkRequest
+from debusine.client.models import LookupChildType
+from debusine.db.models import (
+    Artifact,
+    ArtifactRelation,
+    WorkRequest,
+)
+from debusine.server.collections.lookup import lookup_multiple
 from debusine.server.workflows import workflow_utils
 from debusine.server.workflows.models import (
     LintianWorkflowData,
+    LintianWorkflowDynamicData,
     WorkRequestWorkflowData,
 )
 from debusine.server.workflows.regression_tracking import (
@@ -34,7 +41,9 @@ from debusine.server.workflows.regression_tracking import (
 from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     BackendType,
-    BaseDynamicTaskData,
+    InputArtifact,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LintianData,
     LintianFailOnSeverity,
     LintianInput,
@@ -49,7 +58,7 @@ from debusine.tasks.server import TaskDatabaseInterface
 
 
 class LintianWorkflow(
-    RegressionTrackingWorkflow[LintianWorkflowData, BaseDynamicTaskData]
+    RegressionTrackingWorkflow[LintianWorkflowData, LintianWorkflowDynamicData]
 ):
     """Lintian workflow."""
 
@@ -296,28 +305,69 @@ class LintianWorkflow(
 
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> BaseDynamicTaskData:
+    ) -> LintianWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
 
         :subject: package name of ``source_artifact``
+        :parameter_summary: package name_version
+        :source_artifact_id: id of the source artifact
+        :binary_artifacts_ids: ids of the binary artifacts
         """
-        source_data = workflow_utils.source_package_data(self)
-        return BaseDynamicTaskData(
+        source_artifact = workflow_utils.source_package(self)
+        source_data = SourcePackage.create_data(source_artifact.data)
+
+        binary_artifacts_results = lookup_multiple(
+            self.data.binary_artifacts,
+            self.workspace,
+            user=self.work_request.created_by,
+            workflow_root=self.work_request.workflow_root,
+            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
+        )
+        return LintianWorkflowDynamicData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
+            source_artifact_id=source_artifact.id,
+            binary_artifacts_ids=[
+                result.artifact.id
+                for result in binary_artifacts_results
+                if result.artifact is not None
+            ],
         )
 
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return source_artifact and the binary artifacts."""
+        return [
+            InputArtifactSingle(
+                lookup=self.data.source_artifact,
+                label="source_artifact",
+                artifact_id=(
+                    None
+                    if self.dynamic_data is None
+                    else self.dynamic_data.source_artifact_id
+                ),
+            ),
+            InputArtifactMultiple(
+                lookup=self.data.binary_artifacts,
+                label="binary_artifacts",
+                artifact_ids=(
+                    None
+                    if self.dynamic_data is None
+                    else self.dynamic_data.binary_artifacts_ids
+                ),
+            ),
+        ]
+
     def _extract_artifact_details(
         self, artifact: Artifact | None
-    ) -> tuple[str | None, str | None, WorkRequest | None]:
+    ) -> tuple[str | None, int | None, WorkRequest | None]:
         """Extract details from a ``debian:lintian`` artifact."""
         source_version: str | None
-        url: str | None
+        artifact_id: int | None
         wr: WorkRequest | None
         if artifact is None:
             source_version = None
-            url = None
+            artifact_id = None
             wr = None
         else:
             analyzed_artifact = (
@@ -337,9 +387,9 @@ class LintianWorkflow(
                 ),
             )
             source_version = get_source_package_version(analyzed_data)
-            url = artifact.get_absolute_url()
+            artifact_id = artifact.id
             wr = artifact.created_by_work_request
-        return source_version, url, wr
+        return source_version, artifact_id, wr
 
     @staticmethod
     def compare_qa_results_fine_grained(
@@ -399,11 +449,11 @@ class LintianWorkflow(
             set(reference_artifacts) | set(new_artifacts)
         ):
             reference = reference_artifacts.get(architecture)
-            reference_source_version, reference_url, reference_wr = (
+            reference_source_version, reference_artifact_id, reference_wr = (
                 self._extract_artifact_details(reference)
             )
             new = new_artifacts.get(architecture)
-            new_source_version, new_url, new_wr = (
+            new_source_version, new_artifact_id, new_wr = (
                 self._extract_artifact_details(new)
             )
 
@@ -422,9 +472,9 @@ class LintianWorkflow(
 
             output_data.regression_analysis[architecture] = RegressionAnalysis(
                 original_source_version=reference_source_version,
-                original_url=reference_url,
+                original_artifact_id=reference_artifact_id,
                 new_source_version=new_source_version,
-                new_url=new_url,
+                new_artifact_id=new_artifact_id,
                 status=status,
                 details=details,
             )
