@@ -9,6 +9,7 @@
 
 """Unit tests for Autopkgtest work request plugin."""
 import textwrap
+from typing import ClassVar, override
 
 from debusine.db.playground import scenarios
 from debusine.web.views.files import LogFileWidget
@@ -48,6 +49,31 @@ from debusine.web.views.autopkgtest import (
 class AutopkgtestViewWorkRequestPluginTests(TestCase):
     """Tests for AutopkgtestViewWorkRequestPlugin."""
 
+    environment_artifact: ClassVar[Artifact]
+    source_artifact: ClassVar[Artifact]
+
+    @override
+    @classmethod
+    def setUpTestData(cls) -> None:
+        super().setUpTestData()
+        cls.environment_artifact, _ = cls.playground.create_artifact(
+            paths=["system.tar.xz"],
+            category=ArtifactCategory.SYSTEM_TARBALL,
+            data={
+                "vendor": "debian",
+                "codename": "bookworm",
+                "architecture": "amd64",
+                "variant": "",
+            },
+            create_files=True,
+        )
+        cls.source_artifact, _ = cls.playground.create_artifact(
+            paths=["hello.dsc"],
+            category=ArtifactCategory.SOURCE_PACKAGE,
+            data={"name": "hello", "version": "1.0", "type": "dpkg"},
+            create_files=True,
+        )
+
     def create_work_request_for_artifacts(
         self,
         environment_artifact: Artifact,
@@ -125,25 +151,15 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         artifact.save()
         return artifact
 
+    def test_is_enabled(self) -> None:
+        work_request: WorkRequest = self.create_work_request_for_artifacts(
+            self.environment_artifact, self.source_artifact, []
+        )
+        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
+        self.assertTrue(autopkgtest_view.is_enabled())
+
     def test_get_context_data_simple(self) -> None:
         """get_context_data returns the expected data for a simple case."""
-        environment_artifact, _ = self.playground.create_artifact(
-            paths=["system.tar.xz"],
-            category=ArtifactCategory.SYSTEM_TARBALL,
-            data={
-                "vendor": "debian",
-                "codename": "bookworm",
-                "architecture": "amd64",
-                "variant": "",
-            },
-            create_files=True,
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         binary_artifact_1, _ = self.playground.create_artifact(
             paths=["hello-1.deb"], create_files=True
         )
@@ -151,13 +167,13 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             paths=["hello-2.deb"], create_files=True
         )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact,
-            source_artifact,
+            self.environment_artifact,
+            self.source_artifact,
             [binary_artifact_1, binary_artifact_2],
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            environment_id=self.environment_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[
                 binary_artifact_1.id,
                 binary_artifact_2.id,
@@ -200,9 +216,9 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
                     "needs_internet": "run",
                     "source_artifact": {
                         "files": ["hello.dsc"],
-                        "id": source_artifact.id,
-                        "lookup": source_artifact.id,
-                        "artifact": source_artifact,
+                        "id": self.source_artifact.id,
+                        "lookup": self.source_artifact.id,
+                        "artifact": self.source_artifact,
                     },
                     "source_name": "hello",
                     "source_version": "1.0",
@@ -227,23 +243,6 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_get_context_data_with_context_artifacts(self) -> None:
         """Any context artifacts show up in the context data."""
-        environment_artifact, _ = self.playground.create_artifact(
-            paths=["system.tar.xz"],
-            category=ArtifactCategory.SYSTEM_TARBALL,
-            data={
-                "vendor": "debian",
-                "codename": "bookworm",
-                "architecture": "amd64",
-                "variant": "",
-            },
-            create_files=True,
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         context_artifact_1, _ = self.playground.create_artifact(
             paths=["hello-rdep-1.deb"], create_files=True
         )
@@ -251,14 +250,14 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             paths=["hello-rdep-2.deb"], create_files=True
         )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact,
-            source_artifact,
+            self.environment_artifact,
+            self.source_artifact,
             [],
             context_artifacts=[context_artifact_1, context_artifact_2],
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            environment_id=self.environment_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[],
             input_context_artifacts_ids=[
                 context_artifact_1.id,
@@ -288,25 +287,8 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_context_data_no_artifacts(self) -> None:
         """If there are no output artifacts, context data omits that info."""
-        environment_artifact, _ = self.playground.create_artifact(
-            paths=["system.tar.xz"],
-            category=ArtifactCategory.SYSTEM_TARBALL,
-            data={
-                "vendor": "debian",
-                "codename": "bookworm",
-                "architecture": "amd64",
-                "variant": "",
-            },
-            create_files=True,
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
         autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
         context_data = autopkgtest_view.get_context_data()
@@ -316,17 +298,8 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_context_data_no_dynamic_task_data(self) -> None:
         """If there is no dynamic data, context data omits artifact info."""
-        environment_artifact, _ = self.playground.create_artifact(
-            category=ArtifactCategory.SYSTEM_TARBALL
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
         autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
         context_data = autopkgtest_view.get_context_data()
@@ -339,7 +312,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         self.assertEqual(
             context_data["request_data"]["source_artifact"],
             {
-                "lookup": source_artifact.id,
+                "lookup": self.source_artifact.id,
                 "id": None,
                 "files": [],
                 "artifact": None,
@@ -351,18 +324,12 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         environment_artifact, _ = self.playground.create_artifact(
             category=ArtifactCategory.SYSTEM_TARBALL
         )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            environment_artifact, self.source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
             environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
@@ -382,18 +349,12 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             category=ArtifactCategory.TEST,
             create_files=True,
         )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            environment_artifact, self.source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
             environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
@@ -407,27 +368,18 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_context_data_missing_source_artifact(self) -> None:
         """If the source artifact is missing, context data omits its files."""
-        environment_artifact, _ = self.playground.create_artifact(
-            category=ArtifactCategory.SYSTEM_TARBALL
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            environment_id=self.environment_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
-        source_artifact_id = source_artifact.id
-        source_artifact.files.clear()
-        source_artifact.delete()
+        source_artifact_id = self.source_artifact.id
+        self.source_artifact.files.clear()
+        self.source_artifact.delete()
         autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
         context_data = autopkgtest_view.get_context_data()
         self.assertEqual(
@@ -442,28 +394,14 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_context_data_source_artifact_wrong_category(self) -> None:
         """We cope with the source artifact having an odd category."""
-        environment_artifact, _ = self.playground.create_artifact(
-            paths=["system.tar.xz"],
-            category=ArtifactCategory.SYSTEM_TARBALL,
-            data={
-                "vendor": "debian",
-                "codename": "bookworm",
-                "architecture": "amd64",
-                "variant": "",
-            },
-            create_files=True,
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.TEST,
-            create_files=True,
-        )
+        self.source_artifact.category = ArtifactCategory.TEST
+        self.source_artifact.save()
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            environment_id=self.environment_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
@@ -478,15 +416,6 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_context_data_missing_binary_artifact(self) -> None:
         """If a binary artifact is missing, context data omits its files."""
-        environment_artifact, _ = self.playground.create_artifact(
-            category=ArtifactCategory.SYSTEM_TARBALL
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         binary_artifact_1, _ = self.playground.create_artifact(
             paths=["hello-1.deb"], create_files=True
         )
@@ -494,11 +423,11 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             paths=["hello-2.deb"], create_files=True
         )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
-            input_source_artifact_id=source_artifact.id,
+            environment_id=self.environment_artifact.id,
+            input_source_artifact_id=self.source_artifact.id,
             input_binary_artifacts_ids=[
                 binary_artifact_1.id,
                 binary_artifact_2.id,
@@ -531,9 +460,6 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_get_context_data_skips_incomplete_files(self) -> None:
         """get_context_data() skips incomplete files."""
-        environment_artifact, _ = self.playground.create_artifact(
-            category=ArtifactCategory.SYSTEM_TARBALL
-        )
         source_artifact, _ = self.playground.create_artifact(
             paths=["hello.dsc"],
             category=ArtifactCategory.SOURCE_PACKAGE,
@@ -542,10 +468,10 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             skip_add_files_in_store=True,
         )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, source_artifact, []
         )
         work_request.dynamic_task_data = AutopkgtestDynamicData(
-            environment_id=environment_artifact.id,
+            environment_id=self.environment_artifact.id,
             input_source_artifact_id=source_artifact.id,
             input_binary_artifacts_ids=[],
         ).dict()
@@ -699,25 +625,8 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
 
     def test_show_configured_task_data(self) -> None:
         """The view shows configured task data if present."""
-        environment_artifact, _ = self.playground.create_artifact(
-            paths=["system.tar.xz"],
-            category=ArtifactCategory.SYSTEM_TARBALL,
-            data={
-                "vendor": "debian",
-                "codename": "bookworm",
-                "architecture": "amd64",
-                "variant": "",
-            },
-            create_files=True,
-        )
-        source_artifact, _ = self.playground.create_artifact(
-            paths=["hello.dsc"],
-            category=ArtifactCategory.SOURCE_PACKAGE,
-            data={"name": "hello", "version": "1.0", "type": "dpkg"},
-            create_files=True,
-        )
         work_request: WorkRequest = self.create_work_request_for_artifacts(
-            environment_artifact, source_artifact, []
+            self.environment_artifact, self.source_artifact, []
         )
 
         # Try unconfigured
